<?php

/*

Comments Template

*/

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<div id="comments" class="fy-comments">

    <header class="fy-comments-header">
        <h2><?php comments_number( esc_html__( 'No comments', 'linguini' ), esc_html__( '1 comment', 'linguini' ), esc_html__( '% comments', 'linguini' ) ); ?></h2>
    </header>

	<?php if ( have_comments() ) { ?>

        <div class="fy-comments-list">
			<?php
			$args = array(
				'style'       => 'div',
				'avatar_size' => 96,
				'short_ping'  => true,
				'callback'    => 'forqy_comments_list'
			);
			wp_list_comments( $args );
			?>
        </div>

	<?php } else { ?>
		<?php if ( comments_open() ) { ?>

            <div class="fy-comments-no">
				<?php esc_html_e( 'You can be the first one to leave a comment.', 'linguini' ); ?>
            </div>

		<?php } ?>
	<?php } ?>

	<?php if ( (int) get_option( 'page_comments' ) > 1 ) { ?>

        <div class="fy-comments-pagination fy-pagination">
			<?php
			$args = array(
				'prev_text' => esc_html__( '&lsaquo; Previous', 'linguini' ),
				'next_text' => esc_html__( 'Next &rsaquo;', 'linguini' )
			);
			paginate_comments_links();
			?>
        </div>

	<?php } ?>

	<?php if ( comments_open() ) { ?>

        <div class="fy-comments-form fy-form">

			<?php
			$commenter = wp_get_current_commenter();
			$req       = get_option( 'require_name_email' );
			$aria_req  = ( $req ? " aria-required='true'" : '' );

			$args = array(
				'id_form'              => 'fy-comments-form',
				'id_submit'            => 'fy-comments-submit',
				'class_submit'         => 'fy-button fy-button-accent',
				'title_reply'          => esc_html__( 'Post a Comment', 'linguini' ),
				'title_reply_to'       => esc_html__( 'Reply to %s', 'linguini' ),
				'cancel_reply_link'    => esc_html__( 'Cancel Reply', 'linguini' ),
				'label_submit'         => esc_html__( 'Submit', 'linguini' ),
				'must_log_in'          => '<div class="fy-comments-must-log-in">' . sprintf( wp_kses( __( 'You must be <a href="%s">logged in</a> to post a comment.', 'linguini' ), array( 'a' => array( 'href' => array() ) ) ), wp_login_url( apply_filters( 'the_permalink', get_permalink() ) ) ) . '</div>',
				'logged_in_as'         => '<div class="fy-comments-logged-in-as">' . sprintf( wp_kses( __( 'Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="Log out of this account">Log out?</a>', 'linguini' ), array( 'a' => array( 'href' => array() ) ) ), admin_url( 'profile.php' ), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink() ) ) ) . '</div>',
				'comment_notes_before' => '',
				'comment_notes_after'  => '',
				'fields'               => apply_filters( 'comment_form_default_fields',
					array(
						'author' => '<div class="fy-comments-form-author fy-field"><label for="author" class="fy-hide">' . esc_html__( 'Your name', 'linguini' ) . '</label><input id="author" class="fy-input" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' placeholder="' . esc_html__( 'Your name', 'linguini' ) . ' ..." /></div>',
						'email'  => '<div class="fy-comments-form-email fy-field"><label for="author" class="fy-hide">' . esc_html__( 'Your email', 'linguini' ) . '</label><input id="email" class="fy-input" name="email" type="text" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' placeholder="' . esc_html__( 'Your email', 'linguini' ) . ' ..." /></div>',
						'url'    => ''
					)
				),
				'comment_field'        => '<div class="fy-comments-form-comment fy-field"><label for="author" class="fy-hide">' . esc_html__( 'Write your comment', 'linguini' ) . '</label><textarea id="comment" class="fy-input fy-textarea" name="comment" cols="45" rows="8" aria-required="true" placeholder="' . esc_html__( 'Write your comment', 'linguini' ) . ' ..."></textarea></div>'
			);
			comment_form( $args );
			?>

        </div>

	<?php } ?>

	<?php if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) { ?>

        <div class="fy-comments-closed">
			<?php esc_html_e( 'Comments are closed.', 'linguini' ); ?>
        </div>

	<?php } ?>

</div>
