<?php

/*

Theme Posts Functions

*/

// Excerpt Length

if ( ! function_exists( 'linguini_excerpt_length' ) ) {

	function linguini_excerpt_length() {
		return 36;
	}

	add_filter( 'excerpt_length', 'linguini_excerpt_length', 999 );

}

// Excerpt More

if ( ! function_exists( 'linguini_excerpt_more' ) ) {

	function linguini_excerpt_more() {
		return ' ...';
	}

	add_filter( 'excerpt_more', 'linguini_excerpt_more', 999 );

}

// Post Meta

if ( ! function_exists( 'linguini_post_meta' ) ) {

	function linguini_post_meta() {
		?>

		<ul class="fy-post-meta">
			<li class="fy-post-meta-date">
				<time class="date updated" itemprop="datePublished" datetime="<?php the_time( 'Y-m-d' ); ?>">
					<a href="<?php the_permalink(); ?>">
						<?php the_time( get_option( 'date_format' ) ); ?>
					</a>
				</time>
			</li>

			<li class="fy-post-author fy-hide vcard author" itemprop="author">
				<span class="fn"><?php the_author(); ?></span>
			</li>
			<li class="fy-post-date-modified fy-hide">
				<time class="date updated" itemprop="dateModified" datetime="<?php the_time( 'Y-m-d' ); ?>">
					<?php the_modified_date( get_option( 'date_format' ) ); ?>
				</time>
			</li>
		</ul>

		<?php
	}

}

// Post Taxonomies

if ( ! function_exists( 'linguini_post_terms' ) ) {

	function linguini_post_terms() {
		global $post;
		?>

		<?php if ( has_term( '', 'ingredient' ) ) { ?>
			<div class="fy-post-taxonomies">
				<h3><?php esc_html_e( 'Ingredients', 'linguini' ); ?></h3>
				<?php if ( get_theme_mod( 'fy_menu_filter_by_ingredients' ) == 'disabled' ) { ?>
					<?php linguini_terms_post( $post->ID, 'ingredient', 0 ); ?>
				<?php } else { ?>
					<?php linguini_terms_post( $post->ID, 'ingredient', 1 ); ?>
				<?php } ?>
			</div>
		<?php } ?>

		<?php if ( has_term( '', 'section' ) ) { ?>
			<div class="fy-post-taxonomies">
				<h3><?php esc_html_e( 'Sections', 'linguini' ); ?></h3>
				<?php linguini_terms_post( $post->ID, 'section' ); ?>
			</div>
		<?php } ?>

		<?php if ( has_term( '', 'category-event' ) ) { ?>
			<div class="fy-post-taxonomies">
				<h3><?php esc_html_e( 'Categories', 'linguini' ); ?></h3>
				<?php linguini_terms_post( $post->ID, 'category-event' ); ?>
			</div>
		<?php } ?>

		<?php if ( has_term( '', 'category-gallery' ) ) { ?>
			<div class="fy-post-taxonomies">
				<h3><?php esc_html_e( 'Categories', 'linguini' ); ?></h3>
				<?php linguini_terms_post( $post->ID, 'category-gallery' ); ?>
			</div>
		<?php } ?>

		<?php if ( has_category() ) { ?>
			<div class="fy-post-taxonomies">
				<h3><?php esc_html_e( 'Categories', 'linguini' ); ?></h3>
				<?php
				$categories = get_the_category();
				$separator  = ', ';
				$output     = '';
				if ( $categories ) {
					$output .= '<ul class="fy-terms">';
					foreach ( $categories as $category ) {
						$output .= '<li class="fy-term-item">';
						$output .= '<a href="' . get_category_link( $category->term_id ) . '" title="' . esc_attr( sprintf( esc_html__( 'View all posts in %s', 'linguini' ), $category->name ) ) . '">' . $category->cat_name . '</a>';
						$output .= '</li>';
					}
					$output .= '</ul>';
					echo trim( $output, $separator );
				}
				?>
			</div>
		<?php } ?>

		<?php if ( has_tag() ) { ?>
			<div class="fy-post-taxonomies">
				<h3><?php esc_html_e( 'Tags', 'linguini' ); ?></h3>
				<?php the_tags( '<ul class="fy-terms"><li class="fy-term-item">', '</li><li class="fy-term-item">', '</li></ul>' ); ?>
			</div>
		<?php } ?>

		<?php
	}

}

// Event Location

if ( ! function_exists( 'linguini_event_location' ) ) {

	function linguini_event_location( $args = '' ) {
		$defaults = array( 'heading' => true, 'title' => true, 'address' => true );
		$r        = wp_parse_args( $args, $defaults );
		?>

		<div class="fy-post-location" itemprop="location" itemscope itemtype="https://schema.org/Place">
			<?php if ( forqy_meta( 'fy_event_location' ) ) { ?>
				<?php if ( $r['heading'] === true ) { ?>
					<h3 class="fy-post-location-title location<?php if ( $r['title'] == false ) { ?> fy-hide<?php } ?>"
					    itemprop="name">
						<?php echo esc_attr( forqy_meta( 'fy_event_location' ) ); ?>
					</h3>
				<?php } else { ?>
					<div class="fy-post-location-title location<?php if ( $r['title'] == false ) { ?> fy-hide<?php } ?>"
					     itemprop="name">
						<?php echo esc_attr( forqy_meta( 'fy_event_location' ) ); ?>
					</div>
				<?php } ?>
			<?php } ?>

			<?php if ( forqy_meta( 'fy_event_location_street' ) || forqy_meta( 'fy_event_location_city' ) || forqy_meta( 'fy_event_location_state' ) ) { ?>

				<ul class="fy-event-meta fy-post-meta<?php if ( $r['address'] == false ) { ?> fy-hide<?php } ?>"
				    itemprop="address" itemscope itemtype="https://schema.org/PostalAddress">
					<?php if ( forqy_meta( 'fy_event_location_street' ) ) { ?>
						<li class="fy-post-location-street" itemprop="streetAddress">
							<?php echo esc_attr( forqy_meta( 'fy_event_location_street' ) ); ?>
						</li>
					<?php } ?>

					<?php if ( forqy_meta( 'fy_event_location_city' ) ) { ?>
						<li class="fy-post-location-city" itemprop="addressLocality">
							<?php echo esc_attr( forqy_meta( 'fy_event_location_city' ) ); ?>
						</li>
					<?php } ?>

					<?php if ( forqy_meta( 'fy_event_location_state' ) ) { ?>
						<li class="fy-post-location-state" itemprop="addressRegion">
							<?php echo esc_attr( forqy_meta( 'fy_event_location_state' ) ); ?>
						</li>
					<?php } ?>
				</ul>

			<?php } ?>

		</div>

		<?php
	}

}

// Event Tickets

if ( ! function_exists( 'linguini_event_tickets' ) ) {

	function linguini_event_tickets() {
		?>

		<div class="fy-post-tickets" itemprop="offers" itemscope itemtype="https://schema.org/AggregateOffer">

			<?php if ( forqy_meta( 'fy_event_status' ) ) { ?>
				<div class="fy-tickets-status">
					<?php echo esc_attr( forqy_meta( 'fy_event_status' ) ); ?>
				</div>
			<?php } ?>

			<?php if ( forqy_meta( 'fy_event_price' ) ) { ?>
				<div class="fy-tickets-price" itemprop="lowPrice">
					<?php echo esc_attr( forqy_meta( 'fy_event_price' ) ); ?>
				</div>
			<?php } ?>

			<?php if ( forqy_meta( 'fy_event_button' ) && forqy_meta( 'fy_event_button_url' ) ) { ?>
				<div class="fy-post-button">
					<a href="<?php echo esc_url( forqy_meta( 'fy_event_button_url' ) ); ?>"
					   class="fy-button fy-button-bordered" itemprop="url">
						<?php echo esc_attr( forqy_meta( 'fy_event_button' ) ); ?>
					</a>
				</div>
			<?php } ?>
		</div>

		<?php
	}

}

// Publisher Meta

if ( ! function_exists( 'linguini_publisher_meta' ) ) {

	function linguini_publisher_meta() {
		?>

		<div class="fy-hide" itemprop="publisher" itemscope itemtype="https://schema.org/Organization">
			<?php if ( get_theme_mod( 'fy_logo_image' ) ) { ?>
				<div itemprop="logo" itemscope itemtype="https://schema.org/ImageObject">
					<meta itemprop="url" content="<?php echo esc_url( get_theme_mod( 'fy_logo_image' ) ); ?>">
				</div>
			<?php } ?>
			<span itemprop="name"><?php echo esc_attr( get_bloginfo( 'name' ) ); ?></span>
		</div>

		<?php
	}

}