<?php

/*

Scripts

*/

/*
====================================================================================================
Theme Scripts
====================================================================================================
*/

if ( ! function_exists( 'linguini_theme_scripts' ) ) {

	function linguini_theme_scripts() {

		if ( ! is_admin() ) {

			/**
			 * Components
			 */

			// Pace
			wp_enqueue_script( 'pace', trailingslashit( get_template_directory_uri() ) . 'js/components/pace.js', array(
				'jquery'
			), '1.0.2', true );

			// Lazy
			wp_enqueue_script( 'jquery-lazy', trailingslashit( get_template_directory_uri() ) . 'js/components/jquery.lazy.js', array(
				'jquery'
			), '1.7.10', true );

			// Double Tap to Go
			wp_enqueue_script( 'double-tap-to-go', trailingslashit( get_template_directory_uri() ) . 'js/components/doubletaptogo.js', array(
				'jquery'
			), '0.3.0', true );

			// PhotoSwipe
			wp_enqueue_script( 'photoswipe', trailingslashit( get_template_directory_uri() ) . 'js/components/photoswipe.js', array(
				'jquery'
			), '4.1.2', true );
			wp_enqueue_script( 'photoswipe-ui-default', trailingslashit( get_template_directory_uri() ) . 'js/components/photoswipe-ui-default.js', array(
				'jquery',
				'photoswipe'
			), '4.1.2', true );

			// Swiper
			wp_enqueue_script( 'swiper', trailingslashit( get_template_directory_uri() ) . 'js/components/swiper.js', array(
				'jquery',
				'pace'
			), '4.5.0', true );

			/**
			 * Theme
			 */

			// Theme
			wp_enqueue_script( get_template(), trailingslashit( get_template_directory_uri() ) . 'js/linguini.js', array(
				'jquery',
				'pace'
			), '1.0.0', true );

			// Theme
			wp_enqueue_script( get_template() . '-sticky', trailingslashit( get_template_directory_uri() ) . 'js/sticky.js', array(
				'jquery',
			), '1.0.0', true );

			// Navigation
			wp_enqueue_script( get_template() . '-navigation', trailingslashit( get_template_directory_uri() ) . 'js/navigation.js', array(
				'jquery',
				'double-tap-to-go'
			), '1.0.0', true );

			// Lazy
			wp_enqueue_script( get_template() . '-lazy', trailingslashit( get_template_directory_uri() ) . 'vendor/forqy/core/js/lazy.js', array(
				'jquery',
				'jquery-lazy'
			), '1.0.0', true );

			// Images
			wp_enqueue_script( get_template() . '-images', trailingslashit( get_template_directory_uri() ) . 'vendor/forqy/core/js/images.js', array(
				'jquery',
				'photoswipe',
				'photoswipe-ui-default'
			), '1.0.0', true );

		}

		if ( is_singular() && get_option( 'thread_comments' ) && comments_open() ) {
			// Comment Reply
			wp_enqueue_script( 'comment-reply' );
		}

	}

	add_action( 'wp_enqueue_scripts', 'linguini_theme_scripts', 20 );

}

// Remove jQuery Migrate
// https://github.com/cedaro/dequeue-jquery-migrate/blob/develop/dequeue-jquery-migrate.php

if ( ! function_exists( 'linguini_theme_remove_jquery_migrate' ) ) {

	function linguini_theme_remove_jquery_migrate( $scripts ) {

		if ( ! is_admin() && ! empty( $scripts->registered['jquery'] ) ) {
			$jquery_dependencies                 = $scripts->registered['jquery']->deps;
			$scripts->registered['jquery']->deps = array_diff( $jquery_dependencies, array( 'jquery-migrate' ) );
		}

	}

	add_action( 'wp_default_scripts', 'linguini_theme_remove_jquery_migrate' );

}

/*
====================================================================================================
Admin Scripts
====================================================================================================
*/

if ( ! function_exists( 'linguini_admin_scripts' ) ) {

	function linguini_admin_scripts() {

		// Widget Upload

		// Register
		wp_register_script( 'fy-widget-upload', get_template_directory_uri() . '/inc/js/widget-upload.js' );

		// Localize
		$translation_array = array(
			'select_image'       => esc_html__( 'Select image', 'linguini' ),
			'use_selected_image' => esc_html__( 'Use selected image', 'linguini' )
		);
		wp_localize_script( 'fy-widget-upload', 'translation', $translation_array );

		// Enqueue
		wp_enqueue_script( 'fy-widget-upload' );

	}

	add_action( 'admin_enqueue_scripts', 'linguini_admin_scripts' );

}