<?php

/*

Thumbnail Template

*/

global $post;

// Images
$images       = get_post_meta( $post->ID, 'fy-gallery-images', true );
$images_count = $images ? count( $images ) : 0;

// Content
$content = get_the_content();

// Thumbnail
$thumbnail = wp_get_attachment_image_src( get_post_thumbnail_id(), 'fy-medium' );
// Thumbnail Attributes
$thumbnail_attr = array( 'class' => 'fy-image fy-image-responsive js-lazy' );
// Thumbnail Image
$thumbnail_image = $thumbnail[0];
// Thumbnail Width
$thumbnail_width = $thumbnail[1];
// Thumbnail Height
$thumbnail_height = $thumbnail[2];

// Thumbnail Ratio
if ( $thumbnail_width > $thumbnail_height ) {
	$thumbnail_size = 'landscape';
} else if ( $thumbnail_width < $thumbnail_height ) {
	$thumbnail_size = 'portrait';
} else if ( $thumbnail_width == $thumbnail_height ) {
	$thumbnail_size = 'square';
} else {
	$thumbnail_size = 'default';
}
?>

<figure class="fy-post-image">
    <a href="<?php the_permalink(); ?>"
       title="<?php the_title(); ?>"
       class="js-lazy-parent" tabindex="-1">

        <div class="fy-image fy-image-responsive fy-image-<?php echo esc_attr( $thumbnail_size ); ?> js-lazy"
             data-src="<?php echo esc_url( $thumbnail_image ); ?>"></div>

		<?php get_template_part( 'templates/element/loading' ); ?>

        <span class="fy-hide" itemprop="image" itemscope itemtype="https://schema.org/ImageObject">
            <?php the_title(); ?>

			<?php // Image Meta ?>
            <meta itemprop="url" content="<?php echo esc_url( $thumbnail_image ); ?>">
            <meta itemprop="width" content="<?php echo esc_attr( $thumbnail_width ); ?>">
            <meta itemprop="height" content="<?php echo esc_attr( $thumbnail_height ); ?>">
        </span>

		<?php if ( $images_count > '1' && ( get_post_format() == 'gallery' || get_post_type() == 'gallery' ) ) { ?>
            <div class="fy-post-image-counter">
				<?php echo esc_html( $images_count ); ?>
            </div>
		<?php } ?>

		<?php if ( get_post_format() == 'video' || get_post_format() == 'audio' || has_shortcode( $content, 'video' ) || has_shortcode( $content, 'audio' ) || has_shortcode( $content, 'playlist' ) ) { ?>
            <div class="fy-post-play">
				<?php get_template_part( 'images/icons/icon', 'play' ); ?>
                <span class="fy-hide"><?php esc_html_e( 'Play video', 'linguini' ); ?></span>
            </div>
		<?php } ?>
    </a>
</figure>
