/**
 *
 * Navigation
 * v1.0.0
 *
 * Dependencies:
 * jquery
 * double-tap-to-go
 *
 */

jQuery(document).ready(function ($) {
    "use strict";

    // classes
    var CLASS_NAVIGATION_ON_TOP = 'is-on-top';
    var CLASS_NAVIGATION_ACTIVE = 'navigation-active';
    var CLASS_NAVIGATION_CLOSING = 'navigation-closing';

    // selectors
    var doc = $(document);
    var html = $('html');
    var body = $('body');

    var navigation = $('.js-navigation');

    var navigationTrigger = $('.js-navigation-trigger');
    var navigationClose = $('.js-navigation-close');

    var navigationLinkAnchor = navigation.find('a[href*="#"]');
    var navigationLinkAnchorEmpty = navigation.find('a[href="#"]');

    var navigationHasSub = navigation.find('li:has(ul)');

    /**
     * Double Tap To Go
     */

    if (body.innerWidth() >= '1024') {
        navigationHasSub.doubleTapToGo();
    }
    $(window).on('resize', function () {
        if (body.innerWidth() >= '1024') {
            navigationHasSub.doubleTapToGo();
        }
    });

    /**
     * Anchor Links
     */

    navigationLinkAnchorEmpty.on('click', function (e) {
        e.preventDefault();
    });

    /**
     * Mobile
     */

    navigationTrigger.each(function (i, el) {
        $(el).on('click touchstart', function (e) {
            e.preventDefault();

            if (body.hasClass(CLASS_NAVIGATION_ACTIVE)) {
                body.addClass(CLASS_NAVIGATION_CLOSING);

                setTimeout(function () {
                    html.removeClass(CLASS_NAVIGATION_ACTIVE);
                    body.removeClass(CLASS_NAVIGATION_CLOSING);
                    body.removeClass(CLASS_NAVIGATION_ACTIVE);
                }, 250);
            } else {
                html.addClass(CLASS_NAVIGATION_ACTIVE);
                body.addClass(CLASS_NAVIGATION_ACTIVE);
            }
        });
    });
    // close navigation
    navigationClose.each(function (i, el) {
        $(el).on('click touchstart', function () {

            if (body.hasClass(CLASS_NAVIGATION_ACTIVE)) {
                body.addClass(CLASS_NAVIGATION_CLOSING);

                setTimeout(function () {
                    html.removeClass(CLASS_NAVIGATION_ACTIVE);
                    body.removeClass(CLASS_NAVIGATION_CLOSING);
                    body.removeClass(CLASS_NAVIGATION_ACTIVE);
                }, 250);
            }
        });
    });
    // close navigation on click to anchor link
    navigationLinkAnchor.each(function (i, el) {
        $(el).on('click touchstart', function () {

            if (body.hasClass(CLASS_NAVIGATION_ACTIVE)) {
                body.addClass(CLASS_NAVIGATION_CLOSING);

                setTimeout(function () {
                    html.removeClass(CLASS_NAVIGATION_ACTIVE);
                    body.removeClass(CLASS_NAVIGATION_CLOSING);
                    body.removeClass(CLASS_NAVIGATION_ACTIVE);
                }, 250);
            }
        });
    });
    // close navigation on esc
    $(document).keyup(function (e) {
        if (e.keyCode === 27) {
            if (body.hasClass(CLASS_NAVIGATION_ACTIVE)) {
                body.addClass(CLASS_NAVIGATION_CLOSING);

                setTimeout(function () {
                    html.addClass(CLASS_NAVIGATION_ACTIVE);
                    body.removeClass(CLASS_NAVIGATION_CLOSING);
                    body.removeClass(CLASS_NAVIGATION_ACTIVE);
                }, 250);
            }
        }
    });

    /**
     * Accessibility
     */

    // items with children on focus
    $('.menu-item-has-children a').focus(function () {
        $(this).siblings('.sub-menu').parent('li').addClass('focus');
    }).blur(function () {
        $(this).siblings('.sub-menu').parent('li').removeClass('focus');
    });
    // Sub-menu
    $('.sub-menu a').focus(function () {
        $(this).parents('.sub-menu').parent('li').addClass('focus');
    }).blur(function () {
        $(this).parents('.sub-menu').parent('li').removeClass('focus');
    });

    /**
     * Class
     */

    function forqyNavigationClass() {
        var currentTop = doc.scrollTop();

        if (currentTop === 0) {
            navigation.addClass(CLASS_NAVIGATION_ON_TOP);
        } else {
            navigation.removeClass(CLASS_NAVIGATION_ON_TOP);
        }
    }

    forqyNavigationClass();

    // on scroll
    $(window).on('scroll touchmove', function () {
        forqyNavigationClass();
    });

});